/*
 * User GPIB Include File
 */

#ifndef IFIS_UGPIB_H
#define IFIS_UGPIB_H

#ifdef __cplusplus
extern "C" {
#endif

typedef short	Addr4882_t;	

extern int		ibsta;
extern int		iberr;
extern unsigned int	ibcnt;
extern long 		ibcntl;

#define REOS	0x0400	
#define XEOS	0x0800
#define BIN	0x1000

#define DCL	0x14		
#define GET	0x08	
#define GTL	0x01
#define LAD	0x20
#define LLO	0x11	
#define PPC	0x05
#define PPD	0x70		
#define PPE	0x60		
#define PPU	0x15		
#define SDC	0x04		
#define SPD	0x19		
#define SPE	0x18		
#define TAD	0x40		
#define TCT	0x09	
#define UNL	0x3f		
#define UNT	0x5f		


#define ERR	(1<<15)		
#define TIMO	(1<<14)		
#define END	(1<<13)		
#define SRQI	(1<<12)		
#define RQS	(1<<11)		
#define SPOLL	(1<<10)		
#define EVENT	(1<<9)		
#define CMPL	(1<<8)		
#define LOK	(1<<7)		
#define REM	(1<<6)		
#define CIC	(1<<5)		
#define ATN	(1<<4)		
#define TACS	(1<<3)		
#define LACS	(1<<2)		
#define DTAS	(1<<1)		
#define DCAS	(1<<0)		


#define EDVR	0		
#define ECIC	1		
#define ENOL	2		
#define EADR	3		
#define EARG	4		
#define ESAC	5		
#define EABO	6		
#define ENEB	7		
#define EDMA	8		
#define EBTO	9		
#define EOIP	10	
#define ECAP	11		
#define EFSO	12		
#define EOWN 	13		
#define EBUS	14		
#define ESTB	15		
#define ESRQ	16		
#define ETAB	20		
#define ELCK	21		


#define TNONE	0		
#define T10us	1		
#define T30us	2		
#define T100us	3		
#define T300us	4		
#define T1ms	5		
#define T3ms	6		
#define T10ms	7		
#define T30ms	8		
#define T100ms	9		
#define T300ms	10		
#define T1s	11		
#define T3s	12		
#define T10s	13		
#define T30s	14		
#define T100s	15		
#define T300s	16		
#define T1000s	17		


#define ValidDAV  ((short)0x0001)
#define ValidNDAC ((short)0x0002)
#define ValidNRFD ((short)0x0004)
#define ValidIFC  ((short)0x0008)
#define ValidREN  ((short)0x0010)
#define ValidSRQ  ((short)0x0020)
#define ValidATN  ((short)0x0040)
#define ValidEOI  ((short)0x0080)
#define BusDAV    ((short)0x0100) 
#define BusNDAC   ((short)0x0200) 
#define BusNRFD   ((short)0x0400) 
#define BusIFC    ((short)0x0800) 
#define BusREN    ((short)0x1000) 
#define BusSRQ    ((short)0x2000) 
#define BusATN    ((short)0x4000) 
#define BusEOI    ((short)0x8000) 



#define BUS_DAV         BusDAV
#define BUS_NDAC        BusNDAC
#define BUS_NRFD        BusNRFD
#define BUS_IFC         BusIFC
#define BUS_REN         BusREN
#define BUS_SRQ         BusSRQ
#define BUS_ATN         BusATN
#define BUS_EOI         BusEOI




#define IbcPAD		0x0001	
#define IbcSAD		0x0002	
#define IbcTMO		0x0003	
#define IbcEOT		0x0004	
#define IbcPPC		0x0005	
#define IbcREADDR	0x0006	
#define IbcAUTOPOLL	0x0007	
#define IbcCICPROT	0x0008	
#define IbcIRQ		0x0009	
#define IbcSC		0x000A	
#define IbcSRE		0x000B	
#define IbcEOSrd	0x000C	
#define IbcEOSwrt	0x000D	
#define IbcEOScmp	0x000E	
#define IbcEOSchar	0x000F	
#define IbcPP2		0x0010	
#define IbcTIMING	0x0011	
#define IbcDMA		0x0012	
#define IbcReadAdjust	0x0013	
#define IbcWriteAdjust	0x0014	
#define IbcEventQueue	0x0015	
#define IbcSPollBit	0x0016	
#define IbcSpollBit	0x0016	
#define IbcSendLLO	0x0017	
#define IbcSPollTime	0x0018	
#define IbcPPollTime	0x0019	
#define IbcNoEndBitOnEOS 0x01A	
#define IbcEndBitIsNormal 0x1A	
#define IbcUnAddr	0x001B	
#define IbcSignalNumber	0x001C	
#define IbcHSCableLength 0x01F	
#define IbcLON		0x0022




#define IbaPAD		  IbcPAD            
#define IbaSAD		  IbcSAD            
#define IbaTMO		  IbcTMO            
#define IbaEOT		  IbcEOT            
#define IbaPPC		  IbcPPC            
#define IbaREADDR	  IbcREADDR         
#define IbaAUTOPOLL	  IbcAUTOPOLL       
#define IbaCICPROT	  IbcCICPROT        
#define IbaIRQ		  IbcIRQ            
#define IbaSC		  IbcSC             
#define IbaSRE		  IbcSRE            
#define IbaEOSrd	  IbcEOSrd          
#define IbaEOSwrt	  IbcEOSwrt         
#define IbaEOScmp	  IbcEOScmp         
#define IbaEOSchar	  IbcEOSchar        
#define IbaPP2		  IbcPP2            
#define IbaTIMING	  IbcTIMING         
#define IbaDMA		  IbcDMA            
#define IbaReadAdjust	  IbcReadAdjust     
#define IbaWriteAdjust	  IbcWriteAdjust    
#define IbaEventQueue	  IbcEventQueue     
#define IbaSPollBit	  IbcSPollBit       
#define IbaSpollBit	  IbcSpollBit       
#define IbaSendLLO	  IbcSendLLO        
#define IbaSPollTime	  IbcSPollTime      
#define IbaPPollTime	  IbcPPollTime      
#define IbaNoEndBitOnEOS  IbcNoEndBitOnEOS
#define IbaEndBitIsNormal IbcNoEndBitOnEOS
#define IbaUnAddr	  IbcUnAddr         
#define IbaSignalNumber	  IbcSignalNumber
#define IbaHSCableLength  IbcHSCableLength
#define IbaLON		  IbcLON

#define IbaBNA		  0x200	
#define IbaBaseAddr	  0x201	
#define IbaDmaChannel	  0x202	
#define IbaIrqLevel	  0x203	
#define IbaBaud		  0x204	
#define IbaParity	  0x205	
#define IbaStopBits	  0x206	
#define IbaDataBits	  0x207	
#define IbaComPort	  0x208	
#define IbaComIrqLevel	  0x209	
#define IbaComPortBase	  0x20A	
#define IbaSingleCycleDma 0x20B	


#define NO_SAD		 0	
#define ALL_SAD		-1	


#define NULLend		0x00	
#define NLend		0x01	
#define DABend		0x02	


#define STOPend		0x0100

#define MakeAddr(pad, sad)	((Addr4882_t)(((pad) & 0xFF) | ((sad) << 8)))

#define NOADDR		((Addr4882_t)0xFFFF)

#define GetPAD(val)	((val) & 0xFF)
#define GetSAD(val)	(((val) >> 8) & 0xFF)

/* Function prototypes */
#ifdef __STDC__
extern int ibask(int handle, int option, int *retval);
extern int ibbna(int handle, char *bdname);
extern int ibcac(int handle, int v);
extern int ibclr(int handle);
extern int ibcmd(int handle, void *buffer, long cnt);
extern int ibcmda(int handle, void *buffer, long cnt);
extern int ibconfig(int handle, int option, int value);
extern int ibdev(int boardID, int pad, int sad, int tmo, int eot, int eos);
extern int ibdiag(int handle, void *buffer, long cnt);
extern int ibdma(int handle, int v);
extern int ibeos(int handle, int v);
extern int ibeot(int handle, int v);
extern int ibevent(int handle, short *event);
extern int ibfind(char *bdname);
extern int ibgts(int handle, int v);
extern int ibist(int handle, int v);
extern int iblines(int handle, short *lines);
extern int ibllo(int handle);
extern int ibln(int handle, int padval, int sadval, short *listenflag);
extern int ibloc(int handle);
extern int ibonl(int handle, int v);
extern int ibpad(int handle, int v);
extern int ibpct(int handle);
extern int ibpoke(int handle, int option, int value);
extern int ibppc(int handle, int v);
extern int ibrd(int handle, void *buffer, long cnt);
extern int ibrda(int handle, void *buffer, long cnt);
extern int ibrdf(int handle, char *flname);
extern int ibrdkey(int handle, void *buffer, int cnt);
extern int ibrpp(int handle, char *ppr);
extern int ibrsc(int handle, int v);
extern int ibrsp(int handle, char *spr);
extern int ibrsv(int handle, int v);
extern int ibsad(int handle, int v);
extern int ibsgnl(int handle, int v);
extern int ibsic(int handle);
extern int ibsre(int handle, int v);
extern int ibsrq(void (*func)(void));
extern int ibstop(int handle);
extern int ibtmo(int handle, int v);
extern int ibtrap(int  mask, int mode);
extern int ibtrg(int handle);
extern int ibwait(int handle, int mask);
extern int ibwrt(int handle, void *buffer, long cnt);
extern int ibwrta(int handle, void *buffer, long cnt);
extern int ibwrtf(int handle, char *flname);
extern int ibwrtkey(int handle, void *buffer, int cnt);
extern int ibxtrc(int handle, void *buffer, long cnt);

extern void AllSpoll(int boardID, Addr4882_t *addrlist, short *resultlist);
extern void DevClear(int boardID, Addr4882_t address);
extern void DevClearList(int boardID, Addr4882_t *addrlist);
extern void EnableLocal(int boardID, Addr4882_t *addrlist);
extern void EnableRemote(int boardID, Addr4882_t *addrlist);
extern void FindLstn(int boardID, Addr4882_t *padlist, Addr4882_t *resultlist, int limit);
extern void FindRQS(int boardID, Addr4882_t *addrlist, short *result);
extern void PPoll(int boardID, short *result);
extern void PPollConfig(int boardID, Addr4882_t address, int dataLine, int lineSense);
extern void PPollUnconfig(int boardID, Addr4882_t *addrlist);
extern void PassControl(int boardID, Addr4882_t address);
extern void RcvRespMsg(int boardID, void *buffer, long cnt, int termination);
extern void ReadStatusByte(int boardID, Addr4882_t address, short *result);
extern void Receive(int boardID, Addr4882_t address, void *buffer, long cnt, int termination);
extern void ReceiveSetup(int boardID, Addr4882_t address);
extern void ResetSys(int boardID, Addr4882_t *addrlist);
extern void Send(int boardID, Addr4882_t address, void *buffer, long datacnt, int eotmode);
extern void SendCmds(int boardID, void *buffer, long cnt);
extern void SendDataBytes(int boardID, void *buffer, long cnt, int eotmode);
extern void SendIFC(int boardID);
extern void SendLLO(int boardID);
extern void SendList(int boardID, Addr4882_t *addrlist, void *buffer, long datacnt, int eotmode);
extern void SendSetup(int boardID, Addr4882_t *addrlist);
extern void SetRWLS(int boardID, Addr4882_t *addrlist);
extern void TestSRQ(int boardID, short *result);
extern void TestSys(int boardID, Addr4882_t *addrlist, short *resultlist);
extern void Trigger(int boardID, Addr4882_t address);
extern void TriggerList(int boardID, Addr4882_t *addrlist);
extern void WaitSRQ(int boardID, short *result);

#else /* __STDC__ */
extern int ibask();
extern int ibbna();
extern int ibcac();
extern int ibclr();
extern int ibcmd();
extern int ibcmda();
extern int ibconfig();
extern int ibdev();
extern int ibdiag();
extern int ibdma();
extern int ibeos();
extern int ibeot();
extern int ibevent();
extern int ibfind();
extern int ibgts();
extern int ibist();
extern int iblines();
extern int ibllo();
extern int ibln();
extern int ibloc();
extern int ibonl();
extern int ibpad();
extern int ibpct();
extern int ibpoke();
extern int ibppc();
extern int ibrd();
extern int ibrda();
extern int ibrdf();
extern int ibrdkey();
extern int ibrpp();
extern int ibrsc();
extern int ibrsp();
extern int ibrsv();
extern int ibsad();
extern int ibsgnl();
extern int ibsic();
extern int ibsre();
extern int ibsrq();
extern int ibstop();
extern int ibtmo();
extern int ibtrap();
extern int ibtrg();
extern int ibwait();
extern int ibwrt();
extern int ibwrta();
extern int ibwrtf();
extern int ibwrtkey();
extern int ibxtrc();

extern void AllSpoll();
extern void DevClear();
extern void DevClearList();
extern void EnableLocal();
extern void EnableRemote();
extern void FindLstn();
extern void FindRQS();
extern void PPoll();
extern void PPollConfig();
extern void PPollUnconfig();
extern void PassControl();
extern void RcvRespMsg();
extern void ReadStatusByte();
extern void Receive();
extern void ReceiveSetup();
extern void ResetSys();
extern void Send();
extern void SendCmds();
extern void SendDataBytes();
extern void SendIFC();
extern void SendLLO();
extern void SendList();
extern void SendSetup();
extern void SetRWLS();
extern void TestSRQ();
extern void TestSys();
extern void Trigger();
extern void TriggerList();
extern void WaitSRQ();
#endif /* __STDC__ */

#ifdef __cplusplus
} /* extern "C" */
#endif

#endif /* IFIS_UGPIB.H */

