
#ifndef _DSDMOD_H_
#define _DSDMOD_H_
#include <linux/pci.h>
#include <linux/usb.h>
#include "umic/umiad.h"

  /* mapping of minor numbers to card/chan/driver/chan-of-driver */
  #define GETCARD(i) ((i) >> 4)
  #define GETCHAN(i) ((i) & 0xf)
  #define GETDRIV(i) (((i) & 0xc) >> 2)
  #define GETDRCN(i) (((i) & 0x3))

  #define MAX_CARD (16)
  #define SZ_CARD_ID 64

  struct CardStruct;

  #define PFX "%s: "	/* kernel log prefix */


  /*
   * structure identifying the Linux DSD module to the DSD core
   */
  struct LumiModStruct {
    char *_szDid;		/* driver short name		*/
    const char *_szName;	/* driver long name		*/
    const char *_szDvs;		/* driver version		*/

    struct UmiMod *_pum;	/* per card UmiMod		*/
    int * _pfDebug;		/* pointer to debug flag	*/
    struct file_operations *_pFops;


    /* this modules ISA resources */
    int _cMaxIsa;		/* max isa cards		*/
    int *_piIoIsa;		/* ports array			*/
    int *_piIrqIsa;		/* irq array			*/
    UmiAdaptIsa *_padIsa;	/* ISA adaptor descriptor	*/

    struct pci_driver *_pPdr;   /* if PCI supported 		*/
    struct usb_driver *_pUdr;	/* if USB supported		*/
    char *_szProcDir;		/* subdir of /proc/		*/

    /* 
     * default initialization to zero from here 
     */

    int _iMajor;		/* assigned major number	*/


    /*
     * cards allocated and 
     * managed by the specific bus modules
     */
    struct RegCards {
      struct CardStruct *_pca;		/* allocated and managed by bus module	*/
      char _mzId[SZ_CARD_ID];		/* identifies card physically		*/
    } _mprc[MAX_CARD];
  };

  typedef struct LumiModStruct LumiMod ;
  #define isDebug(p) (*((p)->_pfDebug))
  #define plm_pum(p) ((p)->_pum)


  /*
   * allocate a slot.
   *
   * if sz is known, that slot is returned.
   * else a new slot is allocated and assigned to sz
   *
   * once assigned, slots can be released only by reset.
   */
  extern int pdm_allocslot(LumiMod *plm, const char *sz);
  extern int pdm_findslot(LumiMod *pdm, const char *sz);
  extern int pdm_getslot(LumiMod *pdm, const char *sz);
  extern struct CardStruct* pdm_setcard(LumiMod *plm, int i, struct CardStruct *pca);
  extern struct CardStruct* pdm_clrcard(LumiMod *plm, int i);
  extern struct CardStruct* pdm_getcard(LumiMod *plm, int i);
  extern char* pdm_getid(LumiMod *plm, struct CardStruct *pca);



  /* file operations */
  struct inode;
  struct file;
  extern int xxx_open(LumiMod *pdm, struct inode * pin, struct file *fp) ;
  extern int xxx_release(struct inode * pin, struct file *fp);
  extern int xxx_ioctl(struct inode * pin,struct file *fp, unsigned int cmd, unsigned long arg );
  int pdm_init_module(LumiMod *pdm);
  void pdm_cleanup_module(LumiMod *pdm);


  /* enumerator for ISA */
  int enum_isa_devices(LumiMod *);
  int free_isa_devices(LumiMod *);

  /* pci */
  extern int pdm_pci_probe(LumiMod*, struct pci_dev *pdv, const struct pci_device_id *pdi);
  extern void pdm_pci_remove(LumiMod*, struct pci_dev *pdv);

  /* usb */
  extern int pdm_usb_probe(LumiMod*, struct usb_interface *pui, const struct usb_device_id *pdi);
  extern void pdm_usb_disconnect(LumiMod*, struct usb_interface *pui);


#endif
